@@ -35,13 +35,18 @@ XLConnectSettings <- function(pdesc) {
 	# URL to Mirai Solutions GmbH Website
 	options(MiraiSolutions.URL = pdesc$URL)
 	
+	# XLConnect Version
+	options(XLConnect.Version = pdesc$Version)
+	
 	# Date/time format used for conversion to string;
 	# This is used for communicating a string-based date/time
 	# representation to Java which will then convert it to java.util.Date
 	options(XLConnect.dateTimeFormat = "%Y-%m-%d %H:%M:%S")
 	
-	# Turn off Java logging by default
-	setJavaLogLevel("OFF")
+	# Dummy sheet name (used by xlcDump, xlcRestore)
+	options(XLConnect.Sheet = "#xlc#")
+	# Rowname column (used by xlcDump, xlcRestore)
+	options(XLConnect.RownameCol = ".rownames")
 	
 	invisible()
 }
