@@ -27,15 +27,17 @@
 #############################################################################
 
 setGeneric("readNamedRegion",
-	function(object, name, header) standardGeneric("readNamedRegion"))
+	function(object, ...) standardGeneric("readNamedRegion"))
 
 setMethod("readNamedRegion", 
-	signature(object = "workbook", name = "character", header = "logical"), 
-	function(object, name, header) {	
+	signature(object = "workbook"), 
+	function(object, name, header = TRUE, rownames = NULL) {	
 		# returns a list of RDataFrameWrapper Java object references
 		dataFrame <- xlcCall(object, "readNamedRegion", name, header, SIMPLIFY = FALSE)
 		# construct data.frame
-		dataFrame <- lapply(dataFrame, dataframeFromJava)
+		dataFrame <- lapply(dataFrame, function(x) {
+			extractRownames(dataframeFromJava(x), rownames)
+		})
 		names(dataFrame) <- name
 		
 		# Return data.frame directly in case only one data.frame is read
@@ -43,10 +45,3 @@ setMethod("readNamedRegion",
 		else dataFrame
 	}
 )
-
-setMethod("readNamedRegion", 
-		signature(object = "workbook", name = "character", header = "missing"), 
-		function(object, name, header) {	
-			callGeneric(object, name, TRUE)
-		}
-)
