@@ -61,15 +61,55 @@ test.workbook.setMissingValue <- function() {
 	expect <- data.frame(A = c("4.2", "-3.2", "missing", "1.34"), B = c("A", "missing", "C", "D"), stringsAsFactors = FALSE)
 	setMissingValue(wb.xls, value = "missing")
 	writeNamedRegion(wb.xls, data, name = name)
+	# Reset missing value string such that missing value string is read as string
+	setMissingValue(wb.xls, value = NULL)
 	res <- readNamedRegion(wb.xls, name = name)
 	checkEquals(expect, res)
 	
 	# Check that writing and reading the data with a specific missing value string 
 	# returns the original data but with the numeric column as a character and corresonding
-	# missing value (*.xls)
+	# missing value (*.xlsx)
 	expect <- data.frame(A = c("4.2", "-3.2", "missing", "1.34"), B = c("A", "missing", "C", "D"), stringsAsFactors = FALSE)
 	setMissingValue(wb.xlsx, value = "missing")
 	writeNamedRegion(wb.xlsx, data, name = name)
+	# Reset missing value string such that missing value string is read as string
+	setMissingValue(wb.xlsx, value = NULL)
 	res <- readNamedRegion(wb.xlsx, name = name)
 	checkEquals(expect, res)
+	
+	# Check that writing and reading the data with a specific missing value string 
+	# returns the original data (*.xls)
+	setMissingValue(wb.xls, value = "missing")
+	writeNamedRegion(wb.xls, data, name = name)
+	res <- readNamedRegion(wb.xls, name = name)
+	checkEquals(data, res)
+	
+	# Check that writing and reading the data with a specific missing value string 
+	# returns the original data (*.xls)
+	setMissingValue(wb.xlsx, value = "missing")
+	writeNamedRegion(wb.xlsx, data, name = name)
+	res <- readNamedRegion(wb.xlsx, name = name)
+	checkEquals(data, res)
+	
+	# Create workbooks
+	wb.xls <- loadWorkbook(rsrc("resources/testWorkbookMissingValue.xls"), create = FALSE)
+	wb.xlsx <- loadWorkbook(rsrc("resources/testWorkbookMissingValue.xlsx"), create = FALSE)
+	
+	expect <- data.frame(
+		A = c(NA, -3.2, 3.4, NA, 8, NA),
+		B = c("a", NA, "c", "x", "a", "o"),
+		C = c(TRUE, TRUE, FALSE, NA, FALSE, NA),
+		D = as.POSIXct(c("1981-12-01 00:00:00", "1981-12-02 00:00:00", NA, NA, NA, "1981-12-06 00:00:00"), tz = "UTC"),
+		stringsAsFactors = FALSE
+	)
+	
+	# Check that reading data with multiple missing value strings works (*.xls)
+	setMissingValue(wb.xls, value = c("NA", "missing", "empty"))
+	res <- readNamedRegion(wb.xls, name = "Missing1")
+	checkEquals(res, expect)
+	
+	# Check that reading data with multiple missing value strings works (*.xlsx)
+	setMissingValue(wb.xlsx, value = c("NA", "missing", "empty"))
+	res <- readNamedRegion(wb.xlsx, name = "Missing1")
+	checkEquals(res, expect)
 }
